You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by se...@apache.org on 2015/02/02 02:54:18 UTC

[50/50] [abbrv] incubator-ignite git commit: ignite-sql - renamings

ignite-sql - renamings


Project: http://git-wip-us.apache.org/repos/asf/incubator-ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-ignite/commit/aa0ee770
Tree: http://git-wip-us.apache.org/repos/asf/incubator-ignite/tree/aa0ee770
Diff: http://git-wip-us.apache.org/repos/asf/incubator-ignite/diff/aa0ee770

Branch: refs/heads/ignite-sql
Commit: aa0ee770fa9c1bb6b7f93d7ce23bd1ac21ecf32c
Parents: fb4a74c
Author: S.Vladykin <sv...@gridgain.com>
Authored: Mon Feb 2 04:51:10 2015 +0300
Committer: S.Vladykin <sv...@gridgain.com>
Committed: Mon Feb 2 04:51:10 2015 +0300

----------------------------------------------------------------------
 examples/config/example-cache.xml               |   2 +-
 examples/config/filesystem/example-ggfs.xml     |   9 +-
 .../failover/ComputeFailoverExample.java        |   2 +-
 .../datagrid/CachePopularNumbersExample.java    |   2 +-
 .../examples/datagrid/CacheQueryExample.java    |  19 +-
 .../starschema/CacheStarSchemaExample.java      |   2 +-
 .../datagrid/starschema/DimProduct.java         |   6 +-
 .../examples/datagrid/starschema/DimStore.java  |   6 +-
 .../datagrid/starschema/FactPurchase.java       |  10 +-
 .../store/dummy/CacheDummyPersonStore.java      |   2 +-
 .../messaging/MessagingPingPongExample.java     |   2 +-
 .../MemcacheRestExampleNodeStartup.java         |   4 +-
 .../apache/ignite/examples/ComputeExample.java  |   2 -
 .../ignite/examples/MessagingExample.java       |   1 -
 .../ignite/jdbc/JdbcComplexQuerySelfTest.java   |  13 +-
 .../ignite/jdbc/JdbcLocalCachesSelfTest.java    |   2 +-
 .../ignite/jdbc/JdbcMetadataSelfTest.java       |  11 +-
 .../jdbc/JdbcPreparedStatementSelfTest.java     |  31 +-
 .../ignite/jdbc/JdbcResultSetSelfTest.java      |  37 +--
 .../ignite/jdbc/JdbcStatementSelfTest.java      |   9 +-
 .../clients/src/test/resources/spring-cache.xml |   2 +-
 .../src/test/resources/spring-server-node.xml   |   8 +-
 .../test/resources/spring-server-ssl-node.xml   |   8 +-
 .../java/org/apache/ignite/IgniteCache.java     |   7 +
 .../java/org/apache/ignite/IgnitePortables.java |   2 +-
 .../apache/ignite/cache/CacheConfiguration.java |   8 +-
 .../apache/ignite/cache/CacheProjection.java    |   4 +-
 .../cache/query/CacheContinuousQuery.java       |   4 +-
 .../apache/ignite/cache/query/CacheQueries.java | 152 ----------
 .../apache/ignite/cache/query/CacheQuery.java   | 294 ------------------
 .../cache/query/CacheQueryConfiguration.java    | 203 -------------
 .../ignite/cache/query/CacheQueryFuture.java    |  66 -----
 .../cache/query/CacheQueryGroupIndex.java       |  58 ----
 .../ignite/cache/query/CacheQueryMetrics.java   |  60 ----
 .../ignite/cache/query/CacheQuerySqlField.java  | 133 ---------
 .../cache/query/CacheQuerySqlFunction.java      |  67 -----
 .../ignite/cache/query/CacheQueryTextField.java |  33 ---
 .../ignite/cache/query/CacheQueryType.java      |  47 ---
 .../cache/query/CacheQueryTypeMetadata.java     | 196 ------------
 .../cache/query/CacheQueryTypeResolver.java     |  32 --
 .../ignite/cache/query/QueryConfiguration.java  | 203 +++++++++++++
 .../cache/query/QueryContinuousPredicate.java   |   4 +-
 .../apache/ignite/cache/query/QueryMetrics.java |  60 ++++
 .../apache/ignite/cache/query/QueryReducer.java |  19 +-
 .../ignite/cache/query/QueryTypeMetadata.java   | 196 ++++++++++++
 .../ignite/cache/query/QueryTypeResolver.java   |  32 ++
 .../query/annotations/QueryGroupIndex.java      |   9 -
 .../cache/query/annotations/QuerySqlField.java  |  14 +-
 .../cache/query/annotations/QueryTextField.java |   4 +-
 .../configuration/IgniteQueryConfiguration.java |   2 +-
 .../events/IgniteCacheQueryExecutedEvent.java   |   1 +
 .../events/IgniteCacheQueryReadEvent.java       |   1 +
 .../cache/CacheWeakQueryIteratorsHolder.java    |   4 +-
 .../processors/cache/GridCacheAdapter.java      |   1 -
 .../cache/GridCacheProjectionImpl.java          |   1 -
 .../processors/cache/GridCacheProxyImpl.java    |   1 -
 .../processors/cache/IgniteCacheProxy.java      |   6 +
 .../cache/datastructures/GridCacheSetImpl.java  |   1 -
 .../processors/cache/query/CacheQueries.java    | 153 ++++++++++
 .../processors/cache/query/CacheQuery.java      | 295 +++++++++++++++++++
 .../cache/query/CacheQueryFuture.java           |  66 +++++
 .../processors/cache/query/CacheQueryType.java  |  47 +++
 .../query/GridCacheDistributedQueryManager.java |   1 -
 .../cache/query/GridCacheLocalQueryManager.java |   1 -
 .../cache/query/GridCacheQueriesEx.java         |   1 -
 .../cache/query/GridCacheQueriesImpl.java       |   4 +-
 .../cache/query/GridCacheQueriesProxy.java      |   2 +-
 .../cache/query/GridCacheQueryAdapter.java      |   2 +-
 .../cache/query/GridCacheQueryErrorFuture.java  |   1 -
 .../query/GridCacheQueryFutureAdapter.java      |   1 -
 .../cache/query/GridCacheQueryManager.java      |  20 +-
 .../query/GridCacheQueryMetricsAdapter.java     |   4 +-
 .../cache/query/GridCacheQueryType.java         |   4 +-
 .../GridCacheContinuousQueryHandler.java        |   1 +
 .../query/jdbc/GridCacheQueryJdbcTask.java      |   1 -
 .../processors/query/GridQueryProcessor.java    |  61 ++--
 .../cache/GridCacheQueryCommandHandler.java     |   1 -
 .../visor/cache/VisorCacheQueryMetrics.java     |   2 +-
 .../internal/visor/query/VisorQueryTask.java    |   1 -
 .../internal/visor/query/VisorQueryUtils.java   |   2 +-
 modules/core/src/test/config/log4j-test.xml     |   4 +
 .../GridCacheConcurrentTxMultiNodeTest.java     |  23 +-
 .../GridCacheFieldsQueryNoDataSelfTest.java     |   2 +-
 ...CacheFullTextQueryMultithreadedSelfTest.java |   5 +-
 .../cache/GridCacheLuceneQueryIndexTest.java    |   6 +-
 .../cache/GridCacheOffHeapSelfTest.java         |   3 +-
 .../cache/GridCacheQueryEmbeddedValue.java      |   9 +-
 .../cache/GridCacheQueryIndexSelfTest.java      |   5 +-
 .../GridCacheQueryIndexingDisabledSelfTest.java |   2 +-
 .../processors/cache/GridCacheTestValue.java    |   3 +-
 .../processors/cache/GridCacheTestValue2.java   |   3 +-
 .../cache/IgniteTxMultiNodeAbstractTest.java    |   2 +-
 ...achePartitionedPreloadLifecycleSelfTest.java |   2 +-
 ...hePartitionedQueryMultiThreadedSelfTest.java |  11 +-
 ...CacheReplicatedPreloadLifecycleSelfTest.java |   2 +-
 .../GridCacheSwapScanQueryAbstractSelfTest.java |   1 -
 ...ridCacheContinuousQueryAbstractSelfTest.java |   2 +-
 ...dCacheAbstractReduceFieldsQuerySelfTest.java |  13 +-
 ...cheReduceFieldsQueryPartitionedSelfTest.java |   2 +-
 .../ignite/loadtests/mapper/TestObject.java     |   5 +-
 .../core/src/test/webapp/META-INF/gg-config.xml |   8 +-
 .../processors/query/h2/IgniteH2Indexing.java   |  28 +-
 .../query/h2/opt/GridH2AbstractKeyValueRow.java |   2 +-
 .../query/h2/opt/GridH2IndexBase.java           |   4 +-
 .../query/h2/opt/GridH2KeyValueRowOffheap.java  |   2 +-
 .../query/h2/opt/GridH2SpatialIndex.java        |   2 +-
 .../query/h2/opt/GridH2TreeIndex.java           |   4 +-
 .../query/h2/opt/GridLuceneDirectory.java       |   2 +-
 .../query/h2/opt/GridLuceneIndex.java           |   8 +-
 .../query/h2/opt/GridLuceneInputStream.java     |   2 +-
 .../query/h2/opt/GridLuceneOutputStream.java    |   5 +-
 .../query/h2/twostep/GridMapQueryExecutor.java  |   2 +-
 .../h2/twostep/GridReduceQueryExecutor.java     |   2 +-
 .../query/h2/twostep/GridResultPage.java        |   2 +-
 .../GridCacheAbstractFieldsQuerySelfTest.java   |  21 +-
 .../cache/GridCacheAbstractQuerySelfTest.java   |  44 +--
 .../cache/GridCacheCrossCacheQuerySelfTest.java |  18 +-
 .../cache/GridCacheOffHeapAndSwapSelfTest.java  |  12 +-
 .../cache/GridCacheQueryLoadSelfTest.java       |  11 +-
 .../cache/GridCacheQueryMetricsSelfTest.java    |   7 +-
 .../GridCacheQueryMultiThreadedSelfTest.java    |  13 +-
 .../cache/GridCacheQueryTestValue.java          |  20 +-
 ...idCacheReduceQueryMultithreadedSelfTest.java |   5 +-
 .../GridCacheSqlQueryMultiThreadedSelfTest.java |   5 +-
 .../processors/cache/GridCacheSwapSelfTest.java |  12 +-
 .../cache/GridIndexingWithNoopSwapSelfTest.java |   5 +-
 .../GridCacheAtomicFieldsQuerySelfTest.java     |   2 +-
 ...GridCachePartitionedFieldsQuerySelfTest.java |   2 +-
 ...idCachePartitionedHitsAndMissesSelfTest.java |   4 +-
 .../near/GridCachePartitionedQuerySelfTest.java |   2 +-
 .../near/GridCacheQueryNodeRestartSelfTest.java |   7 +-
 .../GridCacheReplicatedFieldsQuerySelfTest.java |   6 +-
 .../GridCacheReplicatedQuerySelfTest.java       |  10 +-
 .../local/GridCacheLocalQuerySelfTest.java      |   2 +-
 .../query/h2/GridH2IndexRebuildTest.java        |  17 +-
 .../query/h2/GridH2IndexingGeoSelfTest.java     |   7 +-
 .../h2/GridIndexingSpiAbstractSelfTest.java     |   4 +-
 .../query/h2/sql/GridQueryParsingTest.java      |  23 +-
 .../loadtests/h2indexing/GridTestEntity.java    |   6 +-
 .../tcp/GridOrderedMessageCancelSelfTest.java   |   9 +-
 .../IgniteCacheQuerySelfTestSuite.java          |   6 +-
 141 files changed, 1487 insertions(+), 1757 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/config/example-cache.xml
----------------------------------------------------------------------
diff --git a/examples/config/example-cache.xml b/examples/config/example-cache.xml
index 9ec2ef2..43c1819 100644
--- a/examples/config/example-cache.xml
+++ b/examples/config/example-cache.xml
@@ -141,7 +141,7 @@
 
         <!-- Allow to index primitive values. -->
         <property name="queryConfiguration">
-            <bean class="org.apache.ignite.cache.query.CacheQueryConfiguration">
+            <bean class="org.apache.ignite.cache.query.QueryConfiguration">
                 <!-- Index primitives. -->
                 <property name="indexPrimitiveKey" value="true"/>
             </bean>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/config/filesystem/example-ggfs.xml
----------------------------------------------------------------------
diff --git a/examples/config/filesystem/example-ggfs.xml b/examples/config/filesystem/example-ggfs.xml
index fb64227..a2644c5 100644
--- a/examples/config/filesystem/example-ggfs.xml
+++ b/examples/config/filesystem/example-ggfs.xml
@@ -27,12 +27,9 @@
     GridGain.start("examples/config/filesystem/example-ggfs.xml");
 -->
 <beans xmlns="http://www.springframework.org/schema/beans"
-       xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:util="http://www.springframework.org/schema/util"
-       xsi:schemaLocation="
-       http://www.springframework.org/schema/beans
-       http://www.springframework.org/schema/beans/spring-beans.xsd
-       http://www.springframework.org/schema/util
-       http://www.springframework.org/schema/util/spring-util.xsd">
+       xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+       xsi:schemaLocation="http://www.springframework.org/schema/beans
+       http://www.springframework.org/schema/beans/spring-beans.xsd">
 
     <!--
         Optional description.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java/org/apache/ignite/examples/compute/failover/ComputeFailoverExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/failover/ComputeFailoverExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/failover/ComputeFailoverExample.java
index fa065aa..1ed7663 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/failover/ComputeFailoverExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/failover/ComputeFailoverExample.java
@@ -20,9 +20,9 @@ package org.apache.ignite.examples.compute.failover;
 import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.examples.*;
+import org.apache.ignite.internal.util.lang.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.apache.ignite.internal.util.lang.*;
 
 import java.util.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
index 1617662..1d3eed4 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
@@ -19,9 +19,9 @@ package org.apache.ignite.examples.datagrid;
 
 import org.apache.ignite.*;
 import org.apache.ignite.cache.*;
-import org.apache.ignite.cache.query.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.dataload.*;
+import org.apache.ignite.internal.processors.cache.query.*;
 
 import javax.cache.processor.*;
 import java.util.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
index a0205d6..9fc5ca1 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
@@ -20,7 +20,8 @@ package org.apache.ignite.examples.datagrid;
 import org.apache.ignite.*;
 import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.affinity.*;
-import org.apache.ignite.cache.query.*;
+import org.apache.ignite.cache.query.annotations.*;
+import org.apache.ignite.internal.processors.cache.query.*;
 import org.apache.ignite.lang.*;
 
 import java.io.*;
@@ -374,27 +375,27 @@ public class CacheQueryExample {
      */
     private static class Person implements Serializable {
         /** Person ID (indexed). */
-        @CacheQuerySqlField(index = true)
+        @QuerySqlField(index = true)
         private UUID id;
 
         /** Organization ID (indexed). */
-        @CacheQuerySqlField(index = true)
+        @QuerySqlField(index = true)
         private UUID orgId;
 
         /** First name (not-indexed). */
-        @CacheQuerySqlField
+        @QuerySqlField
         private String firstName;
 
         /** Last name (not indexed). */
-        @CacheQuerySqlField
+        @QuerySqlField
         private String lastName;
 
         /** Resume text (create LUCENE-based TEXT index for this field). */
-        @CacheQueryTextField
+        @QueryTextField
         private String resume;
 
         /** Salary (indexed). */
-        @CacheQuerySqlField
+        @QuerySqlField
         private double salary;
 
         /** Custom cache key to guarantee that person is always collocated with its organization. */
@@ -450,11 +451,11 @@ public class CacheQueryExample {
      */
     private static class Organization implements Serializable {
         /** Organization ID (indexed). */
-        @CacheQuerySqlField(index = true)
+        @QuerySqlField(index = true)
         private UUID id;
 
         /** Organization name (indexed). */
-        @CacheQuerySqlField(index = true)
+        @QuerySqlField(index = true)
         private String name;
 
         /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/CacheStarSchemaExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/CacheStarSchemaExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/CacheStarSchemaExample.java
index e5a79d4..8dacff3 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/CacheStarSchemaExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/CacheStarSchemaExample.java
@@ -19,8 +19,8 @@ package org.apache.ignite.examples.datagrid.starschema;
 
 import org.apache.ignite.*;
 import org.apache.ignite.cache.*;
-import org.apache.ignite.cache.query.*;
 import org.apache.ignite.examples.datagrid.*;
+import org.apache.ignite.internal.processors.cache.query.*;
 
 import java.util.*;
 import java.util.concurrent.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/DimProduct.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/DimProduct.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/DimProduct.java
index 48fc99a..af1ba4c 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/DimProduct.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/DimProduct.java
@@ -17,7 +17,7 @@
 
 package org.apache.ignite.examples.datagrid.starschema;
 
-import org.apache.ignite.cache.query.*;
+import org.apache.ignite.cache.query.annotations.*;
 
 /**
  * Represents a product available for purchase. In our {@code snowflake} schema a {@code product}
@@ -26,14 +26,14 @@ import org.apache.ignite.cache.query.*;
  */
 public class DimProduct {
     /** Primary key. */
-    @CacheQuerySqlField(index = true)
+    @QuerySqlField(index = true)
     private int id;
 
     /** Product name. */
     private String name;
 
     /** Product list price. */
-    @CacheQuerySqlField
+    @QuerySqlField
     private float price;
 
     /** Available product quantity. */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/DimStore.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/DimStore.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/DimStore.java
index 34585bd..11fe365 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/DimStore.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/DimStore.java
@@ -17,7 +17,7 @@
 
 package org.apache.ignite.examples.datagrid.starschema;
 
-import org.apache.ignite.cache.query.*;
+import org.apache.ignite.cache.query.annotations.*;
 
 /**
  * Represents a physical store location. In our {@code snowflake} schema a {@code store}
@@ -26,11 +26,11 @@ import org.apache.ignite.cache.query.*;
  */
 public class DimStore {
     /** Primary key. */
-    @CacheQuerySqlField(index = true)
+    @QuerySqlField(index = true)
     private int id;
 
     /** Store name. */
-    @CacheQuerySqlField
+    @QuerySqlField
     private String name;
 
     /** Zip code. */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/FactPurchase.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/FactPurchase.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/FactPurchase.java
index ed69be9..fb097a2 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/FactPurchase.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/starschema/FactPurchase.java
@@ -17,7 +17,7 @@
 
 package org.apache.ignite.examples.datagrid.starschema;
 
-import org.apache.ignite.cache.query.*;
+import org.apache.ignite.cache.query.annotations.*;
 
 /**
  * Represents a purchase record. In our {@code snowflake} schema purchase
@@ -26,19 +26,19 @@ import org.apache.ignite.cache.query.*;
  */
 public class FactPurchase {
     /** Primary key. */
-    @CacheQuerySqlField(index = true)
+    @QuerySqlField(index = true)
     private int id;
 
     /** Foreign key to store at which purchase occurred. */
-    @CacheQuerySqlField
+    @QuerySqlField
     private int storeId;
 
     /** Foreign key to purchased product. */
-    @CacheQuerySqlField
+    @QuerySqlField
     private int productId;
 
     /** Purchase price. */
-    @CacheQuerySqlField
+    @QuerySqlField
     private float purchasePrice;
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java/org/apache/ignite/examples/datagrid/store/dummy/CacheDummyPersonStore.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/store/dummy/CacheDummyPersonStore.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/store/dummy/CacheDummyPersonStore.java
index ed47df0..2e7e445 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/store/dummy/CacheDummyPersonStore.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/store/dummy/CacheDummyPersonStore.java
@@ -18,7 +18,7 @@
 package org.apache.ignite.examples.datagrid.store.dummy;
 
 import org.apache.ignite.*;
-import org.apache.ignite.cache.GridCache;
+import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.store.*;
 import org.apache.ignite.examples.datagrid.store.*;
 import org.apache.ignite.lang.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
index a22b2aa..3e3338d 100644
--- a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
@@ -20,9 +20,9 @@ package org.apache.ignite.examples.messaging;
 import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.examples.*;
+import org.apache.ignite.internal.util.lang.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.apache.ignite.internal.util.lang.*;
 
 import java.util.*;
 import java.util.concurrent.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java/org/apache/ignite/examples/misc/client/memcache/MemcacheRestExampleNodeStartup.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/misc/client/memcache/MemcacheRestExampleNodeStartup.java b/examples/src/main/java/org/apache/ignite/examples/misc/client/memcache/MemcacheRestExampleNodeStartup.java
index a6ea36d..2f6bb36 100644
--- a/examples/src/main/java/org/apache/ignite/examples/misc/client/memcache/MemcacheRestExampleNodeStartup.java
+++ b/examples/src/main/java/org/apache/ignite/examples/misc/client/memcache/MemcacheRestExampleNodeStartup.java
@@ -27,10 +27,10 @@ import org.apache.ignite.spi.discovery.tcp.ipfinder.vm.*;
 
 import java.util.*;
 
-import static org.apache.ignite.configuration.IgniteDeploymentMode.*;
 import static org.apache.ignite.cache.CacheAtomicityMode.*;
 import static org.apache.ignite.cache.CachePreloadMode.*;
 import static org.apache.ignite.cache.CacheWriteSynchronizationMode.*;
+import static org.apache.ignite.configuration.IgniteDeploymentMode.*;
 
 /**
  * Starts up an empty node with cache configuration that contains default cache.
@@ -75,7 +75,7 @@ public class MemcacheRestExampleNodeStartup {
         cacheCfg.setPreloadMode(SYNC);
         cacheCfg.setAtomicityMode(TRANSACTIONAL);
 
-        CacheQueryConfiguration qryCfg = new CacheQueryConfiguration();
+        QueryConfiguration qryCfg = new QueryConfiguration();
 
         qryCfg.setIndexPrimitiveKey(true);
         qryCfg.setIndexFixedTyping(false);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java b/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
index 71b9946..28af049 100644
--- a/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
+++ b/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
@@ -19,8 +19,6 @@ package org.apache.ignite.examples;
 
 import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
-import org.apache.ignite.lang.IgniteCallable;
 
 /**
  * Demonstrates broadcasting and unicasting computations within grid projection.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java b/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
index c69c3ab..f1da946 100644
--- a/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
+++ b/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
@@ -19,7 +19,6 @@ package org.apache.ignite.examples;
 
 import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
-import org.apache.ignite.examples.*;
 
 import java.util.concurrent.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcComplexQuerySelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcComplexQuerySelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcComplexQuerySelfTest.java
index 9f5a676..b9ea56e 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcComplexQuerySelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcComplexQuerySelfTest.java
@@ -20,6 +20,7 @@ package org.apache.ignite.jdbc;
 import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.affinity.*;
 import org.apache.ignite.cache.query.*;
+import org.apache.ignite.cache.query.annotations.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
@@ -258,19 +259,19 @@ public class JdbcComplexQuerySelfTest extends GridCommonAbstractTest {
     @SuppressWarnings("UnusedDeclaration")
     private static class Person implements Serializable {
         /** ID. */
-        @CacheQuerySqlField
+        @QuerySqlField
         private final int id;
 
         /** Name. */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private final String name;
 
         /** Age. */
-        @CacheQuerySqlField
+        @QuerySqlField
         private final int age;
 
         /** Organization ID. */
-        @CacheQuerySqlField
+        @QuerySqlField
         private final int orgId;
 
         /**
@@ -297,11 +298,11 @@ public class JdbcComplexQuerySelfTest extends GridCommonAbstractTest {
     @SuppressWarnings("UnusedDeclaration")
     private static class Organization implements Serializable {
         /** ID. */
-        @CacheQuerySqlField
+        @QuerySqlField
         private final int id;
 
         /** Name. */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private final String name;
 
         /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcLocalCachesSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcLocalCachesSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcLocalCachesSelfTest.java
index 244133f..f0681c9 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcLocalCachesSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcLocalCachesSelfTest.java
@@ -55,7 +55,7 @@ public class JdbcLocalCachesSelfTest extends GridCommonAbstractTest {
         cache.setCacheMode(LOCAL);
         cache.setWriteSynchronizationMode(FULL_SYNC);
 
-        CacheQueryConfiguration qryCfg = new CacheQueryConfiguration();
+        QueryConfiguration qryCfg = new QueryConfiguration();
 
         qryCfg.setIndexPrimitiveKey(true);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcMetadataSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcMetadataSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcMetadataSelfTest.java
index 10f9dbf..6d2a84d 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcMetadataSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcMetadataSelfTest.java
@@ -20,6 +20,7 @@ package org.apache.ignite.jdbc;
 import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.affinity.*;
 import org.apache.ignite.cache.query.*;
+import org.apache.ignite.cache.query.annotations.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
@@ -284,15 +285,15 @@ public class JdbcMetadataSelfTest extends GridCommonAbstractTest {
     @SuppressWarnings("UnusedDeclaration")
     private static class Person implements Serializable {
         /** Name. */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private final String name;
 
         /** Age. */
-        @CacheQuerySqlField
+        @QuerySqlField
         private final int age;
 
         /** Organization ID. */
-        @CacheQuerySqlField
+        @QuerySqlField
         private final int orgId;
 
         /**
@@ -317,11 +318,11 @@ public class JdbcMetadataSelfTest extends GridCommonAbstractTest {
     @SuppressWarnings("UnusedDeclaration")
     private static class Organization implements Serializable {
         /** ID. */
-        @CacheQuerySqlField
+        @QuerySqlField
         private final int id;
 
         /** Name. */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private final String name;
 
         /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcPreparedStatementSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcPreparedStatementSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcPreparedStatementSelfTest.java
index 5850f5a..bb3050d 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcPreparedStatementSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcPreparedStatementSelfTest.java
@@ -19,6 +19,7 @@ package org.apache.ignite.jdbc;
 
 import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.query.*;
+import org.apache.ignite.cache.query.annotations.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
@@ -657,63 +658,63 @@ public class JdbcPreparedStatementSelfTest extends GridCommonAbstractTest {
     @SuppressWarnings("UnusedDeclaration")
     private static class TestObject implements Serializable {
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private final int id;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private Boolean boolVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private Byte byteVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private Short shortVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private Integer intVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private Long longVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private Float floatVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private Double doubleVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private BigDecimal bigVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private String strVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private byte[] arrVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private Date dateVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private Time timeVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private Timestamp tsVal;
 
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private URL urlVal;
 
         /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcResultSetSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcResultSetSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcResultSetSelfTest.java
index 1a58580..910ff40 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcResultSetSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcResultSetSelfTest.java
@@ -19,6 +19,7 @@ package org.apache.ignite.jdbc;
 
 import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.query.*;
+import org.apache.ignite.cache.query.annotations.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
@@ -528,75 +529,75 @@ public class JdbcResultSetSelfTest extends GridCommonAbstractTest {
     @SuppressWarnings("UnusedDeclaration")
     private static class TestObject implements Serializable {
         /** */
-        @CacheQuerySqlField
+        @QuerySqlField
         private final int id;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private Boolean boolVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private Byte byteVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private Short shortVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private Integer intVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private Long longVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private Float floatVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private Double doubleVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private BigDecimal bigVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private String strVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private byte[] arrVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private Date dateVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private Time timeVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private Timestamp tsVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private URL urlVal;
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private TestObjectField f1 = new TestObjectField(100, "AAAA");
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private TestObjectField f2 = new TestObjectField(500, "BBBB");
 
         /** */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private TestObjectField f3;
 
         /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcStatementSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcStatementSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcStatementSelfTest.java
index 235738f..1d06ac8 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcStatementSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcStatementSelfTest.java
@@ -19,6 +19,7 @@ package org.apache.ignite.jdbc;
 
 import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.query.*;
+import org.apache.ignite.cache.query.annotations.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
@@ -251,19 +252,19 @@ public class JdbcStatementSelfTest extends GridCommonAbstractTest {
     @SuppressWarnings("UnusedDeclaration")
     private static class Person implements Serializable {
         /** ID. */
-        @CacheQuerySqlField
+        @QuerySqlField
         private final int id;
 
         /** First name. */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private final String firstName;
 
         /** Last name. */
-        @CacheQuerySqlField(index = false)
+        @QuerySqlField(index = false)
         private final String lastName;
 
         /** Age. */
-        @CacheQuerySqlField
+        @QuerySqlField
         private final int age;
 
         /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/clients/src/test/resources/spring-cache.xml
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/resources/spring-cache.xml b/modules/clients/src/test/resources/spring-cache.xml
index a2e62a9..cf22c8f 100644
--- a/modules/clients/src/test/resources/spring-cache.xml
+++ b/modules/clients/src/test/resources/spring-cache.xml
@@ -92,7 +92,7 @@
 
                     <!-- Allow to index primitive values. -->
                     <property name="queryConfiguration">
-                        <bean class="org.apache.ignite.cache.query.CacheQueryConfiguration">
+                        <bean class="org.apache.ignite.cache.query.QueryConfiguration">
                             <!-- Index primitives. -->
                             <property name="indexPrimitiveKey" value="true"/>
                         </bean>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/clients/src/test/resources/spring-server-node.xml
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/resources/spring-server-node.xml b/modules/clients/src/test/resources/spring-server-node.xml
index ccfcf0f..f93aab4 100644
--- a/modules/clients/src/test/resources/spring-server-node.xml
+++ b/modules/clients/src/test/resources/spring-server-node.xml
@@ -153,10 +153,10 @@
                     <property name="queryIndexEnabled" value="true"/>
 
                     <property name="queryConfiguration">
-                        <bean class="org.apache.ignite.cache.query.CacheQueryConfiguration">
+                        <bean class="org.apache.ignite.cache.query.QueryConfiguration">
                             <property name="typeMetadata">
                                 <list>
-                                    <bean class="org.apache.ignite.cache.query.CacheQueryTypeMetadata">
+                                    <bean class="org.apache.ignite.cache.query.QueryTypeMetadata">
                                         <property name="type" value="GridPortablePerson"/>
                                         <property name="ascendingFields">
                                             <map>
@@ -174,7 +174,7 @@
                                             </list>
                                         </property>
                                     </bean>
-                                    <bean class="org.apache.ignite.cache.query.CacheQueryTypeMetadata">
+                                    <bean class="org.apache.ignite.cache.query.QueryTypeMetadata">
                                         <property name="type" value="GridImplicitPortablePerson"/>
                                         <property name="ascendingFields">
                                             <map>
@@ -187,7 +187,7 @@
                                             </map>
                                         </property>
                                     </bean>
-                                    <bean class="org.apache.ignite.cache.query.CacheQueryTypeMetadata">
+                                    <bean class="org.apache.ignite.cache.query.QueryTypeMetadata">
                                         <property name="type" value="GridNoDefPortablePerson"/>
                                         <property name="ascendingFields">
                                             <map>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/clients/src/test/resources/spring-server-ssl-node.xml
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/resources/spring-server-ssl-node.xml b/modules/clients/src/test/resources/spring-server-ssl-node.xml
index 68774da..ac7e3a3 100644
--- a/modules/clients/src/test/resources/spring-server-ssl-node.xml
+++ b/modules/clients/src/test/resources/spring-server-ssl-node.xml
@@ -137,10 +137,10 @@
                     <property name="queryIndexEnabled" value="true"/>
 
                     <property name="queryConfiguration">
-                        <bean class="org.apache.ignite.cache.query.CacheQueryConfiguration">
+                        <bean class="org.apache.ignite.cache.query.QueryConfiguration">
                             <property name="typeMetadata">
                                 <list>
-                                    <bean class="org.apache.ignite.cache.query.CacheQueryTypeMetadata">
+                                    <bean class="org.apache.ignite.cache.query.QueryTypeMetadata">
                                         <property name="type" value="GridPortablePerson"/>
                                         <property name="ascendingFields">
                                             <map>
@@ -158,7 +158,7 @@
                                             </list>
                                         </property>
                                     </bean>
-                                    <bean class="org.apache.ignite.cache.query.CacheQueryTypeMetadata">
+                                    <bean class="org.apache.ignite.cache.query.QueryTypeMetadata">
                                         <property name="type" value="GridImplicitPortablePerson"/>
                                         <property name="ascendingFields">
                                             <map>
@@ -171,7 +171,7 @@
                                             </map>
                                         </property>
                                     </bean>
-                                    <bean class="org.apache.ignite.cache.query.CacheQueryTypeMetadata">
+                                    <bean class="org.apache.ignite.cache.query.QueryTypeMetadata">
                                         <property name="type" value="GridNoDefPortablePerson"/>
                                         <property name="ascendingFields">
                                             <map>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/core/src/main/java/org/apache/ignite/IgniteCache.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteCache.java b/modules/core/src/main/java/org/apache/ignite/IgniteCache.java
index 8430ec4..c0e800a 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteCache.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteCache.java
@@ -215,6 +215,13 @@ public interface IgniteCache<K, V> extends javax.cache.Cache<K, V>, IgniteAsyncS
 
     public Iterable<Entry<K, V>> localEntries(CachePeekMode... peekModes) throws CacheException;
 
+    /**
+     * Gets query metrics.
+     *
+     * @return Metrics.
+     */
+    public QueryMetrics queryMetrics();
+
     public Map<K, V> localPartition(int part) throws CacheException;
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/core/src/main/java/org/apache/ignite/IgnitePortables.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgnitePortables.java b/modules/core/src/main/java/org/apache/ignite/IgnitePortables.java
index 4da163e..167a64f 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgnitePortables.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgnitePortables.java
@@ -254,7 +254,7 @@ import java.util.Date;
  * or for a specific type via {@link org.apache.ignite.portables.PortableTypeConfiguration} instance.
  * <h1 class="header">Query Indexing</h1>
  * Portable objects can be indexed for querying by specifying index fields in
- * {@link org.apache.ignite.cache.query.CacheQueryTypeMetadata} inside of specific {@link CacheConfiguration} instance,
+ * {@link org.apache.ignite.cache.query.QueryTypeMetadata} inside of specific {@link CacheConfiguration} instance,
  * like so:
  * <pre name=code class=xml>
  * ...

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/core/src/main/java/org/apache/ignite/cache/CacheConfiguration.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/cache/CacheConfiguration.java b/modules/core/src/main/java/org/apache/ignite/cache/CacheConfiguration.java
index d5edb86..764fa7e 100644
--- a/modules/core/src/main/java/org/apache/ignite/cache/CacheConfiguration.java
+++ b/modules/core/src/main/java/org/apache/ignite/cache/CacheConfiguration.java
@@ -336,7 +336,7 @@ public class CacheConfiguration extends MutableConfiguration {
     private boolean keepPortableInStore = true;
 
     /** Query configuration. */
-    private CacheQueryConfiguration qryCfg;
+    private QueryConfiguration qryCfg;
 
     /**
      * Flag indicating whether data can be read from backup.
@@ -1756,7 +1756,7 @@ public class CacheConfiguration extends MutableConfiguration {
      *
      * @return Cache query configuration.
      */
-    public CacheQueryConfiguration getQueryConfiguration() {
+    public QueryConfiguration getQueryConfiguration() {
         return qryCfg;
     }
 
@@ -1764,9 +1764,9 @@ public class CacheConfiguration extends MutableConfiguration {
      * Sets query configuration.
      *
      * @param qryCfg Query configuration.
-     * @see org.apache.ignite.cache.query.CacheQueryConfiguration
+     * @see org.apache.ignite.cache.query.QueryConfiguration
      */
-    public void setQueryConfiguration(CacheQueryConfiguration qryCfg) {
+    public void setQueryConfiguration(QueryConfiguration qryCfg) {
         this.qryCfg = qryCfg;
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/core/src/main/java/org/apache/ignite/cache/CacheProjection.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheContinuousQuery.java b/modules/core/src/main/java/org/apache/ignite/cache/query/CacheContinuousQuery.java
index eb5d265..4fa97b7 100644
--- a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheContinuousQuery.java
+++ b/modules/core/src/main/java/org/apache/ignite/cache/query/CacheContinuousQuery.java
@@ -106,7 +106,7 @@ import java.util.*;
  * qry.cancel();
  * </pre>
  * Note that one query instance can be executed only once. After it's cancelled, it's non-operational.
- * If you need to repeat execution, use {@link CacheQueries#createContinuousQuery()} method to create
+ * If you need to repeat execution, use {@link org.apache.ignite.internal.processors.cache.query.CacheQueries#createContinuousQuery()} method to create
  * new query.
  */
 public interface CacheContinuousQuery<K, V> extends AutoCloseable {
@@ -332,7 +332,7 @@ public interface CacheContinuousQuery<K, V> extends AutoCloseable {
      * <p>
      * Note that one query instance can be executed only once.
      * After it's cancelled, it's non-operational.
-     * If you need to repeat execution, use {@link CacheQueries#createContinuousQuery()}
+     * If you need to repeat execution, use {@link org.apache.ignite.internal.processors.cache.query.CacheQueries#createContinuousQuery()}
      * method to create new query.
      *
      * @throws IgniteCheckedException In case of error.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueries.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueries.java b/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueries.java
deleted file mode 100644
index f14f869..0000000
--- a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueries.java
+++ /dev/null
@@ -1,152 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.cache.query;
-
-import org.apache.ignite.internal.*;
-import org.apache.ignite.lang.*;
-import org.jetbrains.annotations.*;
-
-import java.util.*;
-
-/**
- * Facade for creating distributed queries. It contains various {@code 'createXxxQuery(..)'}
- * methods for {@code SQL}, {@code TEXT}, and {@code SCAN} query creation (see {@link CacheQuery}
- * for more information).
- * <p>
- * Instance of {@code CacheQueries} is obtained from cache projection as follows:
- * <pre name="code" class="java">
- * CacheQueries q = GridGain.grid().cache("myCache").queries();
- * </pre>
- */
-public interface CacheQueries<K, V> {
-    /**
-     * Creates user's SQL query, queried class, and query clause which is generally
-     * a where clause. For more information refer to {@link CacheQuery} documentation.
-     *
-     * @param cls Query class.
-     * @param clause Query clause.
-     * @return Created query.
-     */
-    public CacheQuery<Map.Entry<K, V>> createSqlQuery(Class<?> cls, String clause);
-
-    /**
-     * Creates user's SQL query, queried class, and query clause which is generally
-     * a where clause. For more information refer to {@link CacheQuery} documentation.
-     *
-     * @param clsName Query class name.
-     * @param clause Query clause.
-     * @return Created query.
-     */
-    public CacheQuery<Map.Entry<K, V>> createSqlQuery(String clsName, String clause);
-
-    /**
-     * Creates user's SQL fields query for given clause. For more information refer to
-     * {@link CacheQuery} documentation.
-     *
-     * @param qry Query.
-     * @return Created query.
-     */
-    public CacheQuery<List<?>> createSqlFieldsQuery(String qry);
-
-    /**
-     * Creates user's full text query, queried class, and query clause.
-     * For more information refer to {@link CacheQuery} documentation.
-     *
-     * @param clsName Query class name.
-     * @param search Search clause.
-     * @return Created query.
-     */
-    public CacheQuery<Map.Entry<K, V>> createFullTextQuery(String clsName, String search);
-
-    /**
-     * Creates user's full text query, queried class, and query clause.
-     * For more information refer to {@link CacheQuery} documentation.
-     *
-     * @param cls Query class.
-     * @param search Search clause.
-     * @return Created query.
-     */
-    public CacheQuery<Map.Entry<K, V>> createFullTextQuery(Class<?> cls, String search);
-
-    /**
-     * Creates user's predicate based scan query.
-     *
-     * @param filter Scan filter.
-     * @return Created query.
-     */
-    public CacheQuery<Map.Entry<K, V>> createScanQuery(@Nullable IgniteBiPredicate<K, V> filter);
-
-    /**
-     * Creates new continuous query.
-     * <p>
-     * For more information refer to {@link CacheContinuousQuery} documentation.
-     *
-     * @return Created continuous query.
-     * @see CacheContinuousQuery
-     */
-    public CacheContinuousQuery<K, V> createContinuousQuery();
-
-    /**
-     * Forces this cache to rebuild all search indexes of given value type. Sometimes indexes
-     * may hold references to objects that have already been removed from cache. Although
-     * not affecting query results, these objects may consume extra memory. Rebuilding
-     * indexes will remove any redundant references that may have temporarily got stuck
-     * inside in-memory index.
-     *
-     * @param cls Value type to rebuild indexes for.
-     *
-     * @return Future that will be completed when rebuilding of all indexes is finished.
-     */
-    public IgniteInternalFuture<?> rebuildIndexes(Class<?> cls);
-
-    /**
-     * Forces this cache to rebuild all search indexes of given value type. Sometimes indexes
-     * may hold references to objects that have already been removed from cache. Although
-     * not affecting query results, these objects may consume extra memory. Rebuilding
-     * indexes will remove any redundant references that may have temporarily got stuck
-     * inside in-memory index.
-     *
-     * @param typeName Value type name to rebuild indexes for.
-     *
-     * @return Future that will be completed when rebuilding of all indexes is finished.
-     */
-    public IgniteInternalFuture<?> rebuildIndexes(String typeName);
-
-    /**
-     * Forces this cache to rebuild search indexes of all types. Sometimes indexes
-     * may hold references to objects that have already been removed from cache. Although
-     * not affecting query results, these objects may consume extra memory. Rebuilding
-     * indexes will remove any redundant references that may have temporarily got stuck
-     * inside in-memory index.
-     *
-     * @return Future that will be completed when rebuilding of all indexes is finished.
-     */
-    public IgniteInternalFuture<?> rebuildAllIndexes();
-
-    /**
-     * Accumulated metrics for all queries executed for this cache.
-     *
-     * @return Cache query metrics.
-     */
-    public CacheQueryMetrics metrics();
-
-    /**
-     * Resets accumulated metrics.
-     */
-    public void resetMetrics();
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQuery.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQuery.java b/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQuery.java
deleted file mode 100644
index 355f1f1..0000000
--- a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQuery.java
+++ /dev/null
@@ -1,294 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.cache.query;
-
-import org.apache.ignite.cluster.*;
-import org.apache.ignite.lang.*;
-import org.jetbrains.annotations.*;
-
-/**
- * Main API for configuring and executing cache queries.
- * <p>
- * Cache queries are created from {@link CacheQueries} API via any of the available
- * {@code createXXXQuery(...)} methods.
- * <h1 class="header">SQL Queries</h1>
- * {@code SQL} query allows to execute distributed cache
- * queries using standard SQL syntax. All values participating in where clauses
- * or joins must be annotated with {@link CacheQuerySqlField} annotation. Query can be created
- * with {@link CacheQueries#createSqlQuery(Class, String)} method.
- * <h2 class="header">Field Queries</h2>
- * By default {@code select} clause is ignored as query result contains full objects.
- * If it is needed to select individual fields, use {@link CacheQueries#createSqlFieldsQuery(String)} method.
- * This type of query replaces full objects with individual fields. Note that selected fields
- * must be annotated with {@link CacheQuerySqlField} annotation.
- * <h2 class="header">Cross-Cache Queries</h2>
- * You are allowed to query data from several caches. Cache that this query was created on is
- * treated as default schema in this case. Other caches can be referenced by their names.
- * <p>
- * Note that cache name is case sensitive and has to always be specified in double quotes.
- * Here is an example of cross cache query (note that 'replicated' and 'partitioned' are
- * cache names for replicated and partitioned caches accordingly):
- * <pre name="code" class="java">
- * CacheQuery&lt;Map.Entry&lt;Integer, FactPurchase&gt;&gt; storePurchases = cache.queries().createSqlQuery(
- *     Purchase.class,
- *     "from \"replicated\".Store, \"partitioned\".Purchase where Store.id=Purchase.storeId and Store.id=?");
- * </pre>
- * <h2 class="header">Custom functions in SQL queries.</h2>
- * It is possible to write custom Java methods and call then form SQL queries. These methods must be public static
- * and annotated with {@link CacheQuerySqlFunction}. Classes containing these methods must be registered in
- * {@link org.apache.ignite.configuration.IgniteQueryConfiguration#setIndexCustomFunctionClasses(Class[])}.
- * <h1 class="header">Full Text Queries</h1>
- * GridGain supports full text queries based on Apache Lucene engine. This queries are created by
- * {@link CacheQueries#createFullTextQuery(Class, String)} method. Note that all fields that
- * are expected to show up in text query results must be annotated with {@link CacheQueryTextField}
- * annotation.
- * <h1 class="header">Scan Queries</h1>
- * Sometimes when it is known in advance that SQL query will cause a full data scan, or whenever data set
- * is relatively small, the full scan query may be used. This query will iterate over all cache
- * entries, skipping over entries that don't pass the optionally provided key-value filter
- * (see {@link CacheQueries#createScanQuery(org.apache.ignite.lang.IgniteBiPredicate)} method).
- * <h2 class="header">Limitations</h2>
- * Data in GridGain cache is usually distributed across several nodes,
- * so some queries may not work as expected. Keep in mind following limitations
- * (not applied if data is queried from one node only):
- * <ul>
- *     <li>
- *         {@code Group by} and {@code sort by} statements are applied separately
- *         on each node, so result set will likely be incorrectly grouped or sorted
- *         after results from multiple remote nodes are grouped together.
- *     </li>
- *     <li>
- *         Aggregation functions like {@code sum}, {@code max}, {@code avg}, etc.
- *         are also applied on each node. Therefore you will get several results
- *         containing aggregated values, one for each node.
- *     </li>
- *     <li>
- *         Joins will work correctly only if joined objects are stored in
- *         collocated mode or at least one side of the join is stored in
- *         {@link org.apache.ignite.cache.CacheMode#REPLICATED} cache. Refer to
- *         {@link org.apache.ignite.cache.affinity.CacheAffinityKey} javadoc for more information about colocation.
- *     </li>
- * </ul>
- * <h1 class="header">Query usage</h1>
- * As an example, suppose we have data model consisting of {@code 'Employee'} and {@code 'Organization'}
- * classes defined as follows:
- * <pre name="code" class="java">
- * public class Organization {
- *     // Indexed field.
- *     &#64;CacheQuerySqlField(index = true)
- *     private long id;
- *
- *     // Indexed field.
- *     &#64;CacheQuerySqlField(index = true)
- *     private String name;
- *     ...
- * }
- *
- * public class Person {
- *     // Indexed field.
- *     &#64;CacheQuerySqlField(index = true)
- *     private long id;
- *
- *     // Indexed field (Organization ID, used as a foreign key).
- *     &#64;CacheQuerySqlField(index = true)
- *     private long orgId;
- *
- *     // Without SQL field annotation, this field cannot be used in queries.
- *     private String name;
- *
- *     // Not indexed field.
- *     &#64;CacheQuerySqlField
- *     private double salary;
- *
- *     // Index for text search.
- *     &#64;CacheQueryTextField
- *     private String resume;
- *     ...
- * }
- * </pre>
- * Then you can create and execute queries that check various salary ranges like so:
- * <pre name="code" class="java">
- * Cache&lt;Long, Person&gt; cache = G.grid().cache();
- * ...
- * // Create query which selects salaries based on range for all employees
- * // that work for a certain company.
- * CacheQuery&lt;Map.Entry&lt;Long, Person&gt;&gt; qry = cache.queries().createSqlQuery(Person.class,
- *     "from Person, Organization where Person.orgId = Organization.id " +
- *         "and Organization.name = ? and Person.salary &gt; ? and Person.salary &lt;= ?");
- *
- * // Query all nodes to find all cached GridGain employees
- * // with salaries less than 1000.
- * qry.execute("GridGain", 0, 1000);
- *
- * // Query only remote nodes to find all remotely cached GridGain employees
- * // with salaries greater than 1000 and less than 2000.
- * qry.projection(grid.remoteProjection()).execute("GridGain", 1000, 2000);
- * </pre>
- * Here is a possible query that will use Lucene text search to scan all resumes to
- * check if employees have {@code Master} degree:
- * <pre name="code" class="java">
- * CacheQuery&lt;Map.Entry&lt;Long, Person&gt;&gt; mastersQry =
- *     cache.queries().createFullTextQuery(Person.class, "Master");
- *
- * // Query all cache nodes.
- * mastersQry.execute();
- * </pre>
- * <h1 class="header">Geo-Spatial Indexes and Queries</h1>
- * GridGain also support <b>Geo-Spatial Indexes</b>. Here is an example of geo-spatial index:
- * <pre name="code" class="java">
- * private class MapPoint implements Serializable {
- *     // Geospatial index.
- *     &#64;CacheQuerySqlField(index = true)
- *     private com.vividsolutions.jts.geom.Point location;
- *
- *     // Not indexed field.
- *     &#64;CacheQuerySqlField
- *     private String name;
- *
- *     public MapPoint(com.vividsolutions.jts.geom.Point location, String name) {
- *         this.location = location;
- *         this.name = name;
- *     }
- * }
- * </pre>
- * Example of spatial query on the geo-indexed field from above:
- * <pre name="code" class="java">
- * com.vividsolutions.jts.geom.GeometryFactory factory = new com.vividsolutions.jts.geom.GeometryFactory();
- *
- * com.vividsolutions.jts.geom.Polygon square = factory.createPolygon(new Coordinate[] {
- *     new com.vividsolutions.jts.geom.Coordinate(0, 0),
- *     new com.vividsolutions.jts.geom.Coordinate(0, 100),
- *     new com.vividsolutions.jts.geom.Coordinate(100, 100),
- *     new com.vividsolutions.jts.geom.Coordinate(100, 0),
- *     new com.vividsolutions.jts.geom.Coordinate(0, 0)
- * });
- *
- * Map.Entry<String, UserData> records = cache.queries().createSqlQuery(MapPoint.class, "select * from MapPoint where location && ?")
- *     .queryArguments(square)
- *     .execute()
- *     .get();
- * </pre>
- */
-public interface CacheQuery<T> {
-    /** Default query page size. */
-    public static final int DFLT_PAGE_SIZE = 1024;
-
-    /**
-     * Sets result page size. If not provided, {@link #DFLT_PAGE_SIZE} will be used.
-     * Results are returned from queried nodes one page at a tme.
-     *
-     * @param pageSize Page size.
-     * @return {@code this} query instance for chaining.
-     */
-    public CacheQuery<T> pageSize(int pageSize);
-
-    /**
-     * Sets query timeout. {@code 0} means there is no timeout (this
-     * is a default value).
-     *
-     * @param timeout Query timeout.
-     * @return {@code this} query instance for chaining.
-     */
-    public CacheQuery<T> timeout(long timeout);
-
-    /**
-     * Sets whether or not to keep all query results local. If not - only the current page
-     * is kept locally. Default value is {@code true}.
-     *
-     * @param keepAll Keep results or not.
-     * @return {@code this} query instance for chaining.
-     */
-    public CacheQuery<T> keepAll(boolean keepAll);
-
-    /**
-     * Sets whether or not to include backup entries into query result. This flag
-     * is {@code false} by default.
-     *
-     * @param incBackups Query {@code includeBackups} flag.
-     * @return {@code this} query instance for chaining.
-     */
-    public CacheQuery<T> includeBackups(boolean incBackups);
-
-    /**
-     * Sets whether or not to deduplicate query result set. If this flag is {@code true}
-     * then query result will not contain some key more than once even if several nodes
-     * returned entries with the same keys. Default value is {@code false}.
-     *
-     * @param dedup Query {@code enableDedup} flag.
-     * @return {@code this} query instance for chaining.
-     */
-    public CacheQuery<T> enableDedup(boolean dedup);
-
-    /**
-     * Sets optional grid projection to execute this query on.
-     *
-     * @param prj Projection.
-     * @return {@code this} query instance for chaining.
-     */
-    public CacheQuery<T> projection(ClusterGroup prj);
-
-    /**
-     * Executes the query and returns the query future. Caller may decide to iterate
-     * over the returned future directly in which case the iterator may block until
-     * the next value will become available, or wait for the whole query to finish
-     * by calling any of the {@code 'get(..)'} methods on the returned future. If
-     * {@link #keepAll(boolean)} flag is set to {@code false}, then {@code 'get(..)'}
-     * methods will only return the last page received, otherwise all pages will be
-     * accumulated and returned to user as a collection.
-     * <p>
-     * Note that if the passed in grid projection is a local node, then query
-     * will be executed locally without distribution to other nodes.
-     * <p>
-     * Also note that query state cannot be changed (clause, timeout etc.), except
-     * arguments, if this method was called at least once.
-     *
-     * @param args Optional arguments.
-     * @return Future for the query result.
-     */
-    public CacheQueryFuture<T> execute(@Nullable Object... args);
-
-    /**
-     * Executes the query the same way as {@link #execute(Object...)} method but reduces result remotely.
-     *
-     * @param rmtReducer Remote reducer.
-     * @param args Optional arguments.
-     * @return Future for the query result.
-     */
-    public <R> CacheQueryFuture<R> execute(IgniteReducer<T, R> rmtReducer, @Nullable Object... args);
-
-    /**
-     * Executes the query the same way as {@link #execute(Object...)} method but transforms result remotely.
-     *
-     * @param rmtTransform Remote transformer.
-     * @param args Optional arguments.
-     * @return Future for the query result.
-     */
-    public <R> CacheQueryFuture<R> execute(IgniteClosure<T, R> rmtTransform, @Nullable Object... args);
-
-    /**
-     * Gets metrics for this query.
-     *
-     * @return Query metrics.
-     */
-    public CacheQueryMetrics metrics();
-
-    /**
-     * Resets metrics for this query.
-     */
-    public void resetMetrics();
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryConfiguration.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryConfiguration.java b/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryConfiguration.java
deleted file mode 100644
index 9f1cb91..0000000
--- a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryConfiguration.java
+++ /dev/null
@@ -1,203 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.cache.query;
-
-import java.io.*;
-import java.util.*;
-
-/**
- * Query configuration object.
- */
-public class CacheQueryConfiguration implements Serializable {
-    /** */
-    private static final long serialVersionUID = 0L;
-
-    /** Collection of query type metadata. */
-    private Collection<CacheQueryTypeMetadata> typeMeta;
-
-    /** Query type resolver. */
-    private CacheQueryTypeResolver typeRslvr;
-
-    /** */
-    private boolean idxPrimitiveKey;
-
-    /** */
-    private boolean idxPrimitiveVal;
-
-    /** */
-    private boolean idxFixedTyping;
-
-    /** */
-    private boolean escapeAll;
-
-    /**
-     * Default constructor.
-     */
-    public CacheQueryConfiguration() {
-        // No-op.
-    }
-
-    /**
-     * @param cfg Configuration to copy.
-     */
-    public CacheQueryConfiguration(CacheQueryConfiguration cfg) {
-        typeMeta = cfg.getTypeMetadata();
-        typeRslvr = cfg.getTypeResolver();
-        idxPrimitiveKey = cfg.isIndexPrimitiveKey();
-        idxPrimitiveVal = cfg.isIndexPrimitiveValue();
-        idxFixedTyping = cfg.isIndexFixedTyping();
-        escapeAll = cfg.isEscapeAll();
-    }
-
-    /**
-     * Gets collection of query type metadata objects.
-     *
-     * @return Collection of query type metadata.
-     */
-    public Collection<CacheQueryTypeMetadata> getTypeMetadata() {
-        return typeMeta;
-    }
-
-    /**
-     * Sets collection of query type metadata objects.
-     *
-     * @param typeMeta Collection of query type metadata.
-     */
-    public void setTypeMetadata(Collection<CacheQueryTypeMetadata> typeMeta) {
-        this.typeMeta = typeMeta;
-    }
-
-    /**
-     * Gets query type resolver.
-     *
-     * @return Query type resolver.
-     */
-    public CacheQueryTypeResolver getTypeResolver() {
-        return typeRslvr;
-    }
-
-    /**
-     * Sets query type resolver.
-     *
-     * @param typeRslvr Query type resolver.
-     */
-    public void setTypeResolver(CacheQueryTypeResolver typeRslvr) {
-        this.typeRslvr = typeRslvr;
-    }
-
-    /**
-     * Gets flag indicating whether SQL engine should index by key in cases
-     * where key is primitive type
-     *
-     * @return {@code True} if primitive keys should be indexed.
-     */
-    public boolean isIndexPrimitiveKey() {
-        return idxPrimitiveKey;
-    }
-
-    /**
-     * Sets flag indicating whether SQL engine should index by key in cases
-     * where key is primitive type.
-     *
-     * @param idxPrimitiveKey {@code True} if primitive keys should be indexed.
-     */
-    public void setIndexPrimitiveKey(boolean idxPrimitiveKey) {
-        this.idxPrimitiveKey = idxPrimitiveKey;
-    }
-
-    /**
-     * Gets flag indicating whether SQL engine should index by value in cases
-     * where value is primitive type
-     *
-     * @return {@code True} if primitive values should be indexed.
-     */
-    public boolean isIndexPrimitiveValue() {
-        return idxPrimitiveVal;
-    }
-
-    /**
-     * Sets flag indexing whether SQL engine should index by value in cases
-     * where value is primitive type.
-     *
-     * @param idxPrimitiveVal {@code True} if primitive values should be indexed.
-     */
-    public void setIndexPrimitiveValue(boolean idxPrimitiveVal) {
-        this.idxPrimitiveVal = idxPrimitiveVal;
-    }
-
-    /**
-     * This flag essentially controls whether all values of the same type have
-     * identical key type.
-     * <p>
-     * If {@code false}, SQL engine will store all keys in BINARY form to make it possible to store
-     * the same value type with different key types. If {@code true}, key type will be converted
-     * to respective SQL type if it is possible, hence, improving performance of queries.
-     * <p>
-     * Setting this value to {@code false} also means that {@code '_key'} column cannot be indexed and
-     * cannot participate in query where clauses. The behavior of using '_key' column in where
-     * clauses with this flag set to {@code false} is undefined.
-     *
-     * @return {@code True} if SQL engine should try to convert values to their respective SQL
-     *      types for better performance.
-     */
-    public boolean isIndexFixedTyping() {
-        return idxFixedTyping;
-    }
-
-    /**
-     * This flag essentially controls whether key type is going to be identical
-     * for all values of the same type.
-     * <p>
-     * If false, SQL engine will store all keys in BINARY form to make it possible to store
-     * the same value type with different key types. If true, key type will be converted
-     * to respective SQL type if it is possible, which may provide significant performance
-     * boost.
-     *
-     * @param idxFixedTyping {@code True} if SQL engine should try to convert values to their respective SQL
-     *      types for better performance.
-     */
-    public void setIndexFixedTyping(boolean idxFixedTyping) {
-        this.idxFixedTyping = idxFixedTyping;
-    }
-
-    /**
-     * If {@code true}, then table name and all column names in 'create table' SQL
-     * generated for SQL engine are escaped with double quotes. This flag should be set if table name of
-     * column name is H2 reserved word or is not valid H2 identifier (e.g. contains space or hyphen).
-     * <p>
-     * Note if this flag is set then table and column name in SQL queries also must be escaped with double quotes.
-
-     * @return Flag value.
-     */
-    public boolean isEscapeAll() {
-        return escapeAll;
-    }
-
-    /**
-     * If {@code true}, then table name and all column names in 'create table' SQL
-     * generated for SQL engine are escaped with double quotes. This flag should be set if table name of
-     * column name is H2 reserved word or is not valid H2 identifier (e.g. contains space or hyphen).
-     * <p>
-     * Note if this flag is set then table and column name in SQL queries also must be escaped with double quotes.
-
-     * @param escapeAll Flag value.
-     */
-    public void setEscapeAll(boolean escapeAll) {
-        this.escapeAll = escapeAll;
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryFuture.java b/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryFuture.java
deleted file mode 100644
index 6f68f29..0000000
--- a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryFuture.java
+++ /dev/null
@@ -1,66 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.cache.query;
-
-import org.apache.ignite.*;
-import org.apache.ignite.internal.*;
-import org.jetbrains.annotations.*;
-
-import java.util.*;
-
-/**
- * Cache query future returned by query execution.
- * Refer to {@link CacheQuery} documentation for more information.
- */
-public interface CacheQueryFuture<T> extends IgniteInternalFuture<Collection<T>> {
-    /**
-     * Returns number of elements that are already fetched and can
-     * be returned from {@link #next()} method without blocking.
-     *
-     * @return Number of fetched elements which are available immediately.
-     * @throws IgniteCheckedException In case of error.
-     */
-    public int available() throws IgniteCheckedException;
-
-    /**
-     * Returns next element from result set.
-     * <p>
-     * This is a blocking call which will wait if there are no
-     * elements available immediately.
-     *
-     * @return Next fetched element or {@code null} if all the elements have been fetched.
-     * @throws IgniteCheckedException If failed.
-     */
-    @Nullable public T next() throws IgniteCheckedException;
-
-    /**
-     * Checks if all data is fetched by the query.
-     *
-     * @return {@code True} if all data is fetched, {@code false} otherwise.
-     */
-    @Override public boolean isDone();
-
-    /**
-     * Cancels this query future and stop receiving any further results for the query
-     * associated with this future.
-     *
-     * @return {@inheritDoc}
-     * @throws IgniteCheckedException {@inheritDoc}
-     */
-    @Override public boolean cancel() throws IgniteCheckedException;
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryGroupIndex.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryGroupIndex.java b/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryGroupIndex.java
deleted file mode 100644
index e6eaa3c..0000000
--- a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryGroupIndex.java
+++ /dev/null
@@ -1,58 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.cache.query;
-
-import java.lang.annotation.*;
-
-/**
- * Describes group index.
- */
-@Retention(RetentionPolicy.RUNTIME)
-@Target(ElementType.TYPE)
-public @interface CacheQueryGroupIndex {
-    /**
-     * Group index name.
-     *
-     * @return Name.
-     */
-    String name();
-
-    /**
-     * If this index is unique.
-     *
-     * @return True if this index is unique, false otherwise.
-     * @deprecated No longer supported, will be ignored.
-     */
-    @Deprecated
-    boolean unique() default false;
-
-    /**
-     * List of group indexes for type.
-     */
-    @SuppressWarnings("PublicInnerClass")
-    @Retention(RetentionPolicy.RUNTIME)
-    @Target(ElementType.TYPE)
-    public static @interface List {
-        /**
-         * Gets array of group indexes.
-         *
-         * @return Array of group indexes.
-         */
-        CacheQueryGroupIndex[] value();
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryMetrics.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryMetrics.java b/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryMetrics.java
deleted file mode 100644
index 6c99aef..0000000
--- a/modules/core/src/main/java/org/apache/ignite/cache/query/CacheQueryMetrics.java
+++ /dev/null
@@ -1,60 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.cache.query;
-
-/**
- * Cache query metrics used to obtain statistics on query. You can get metrics for
- * particular query via {@link CacheQuery#metrics()} method or accumulated metrics
- * for all queries via {@link CacheQueries#metrics()}.
- */
-public interface CacheQueryMetrics {
-    /**
-     * Gets minimum execution time of query.
-     *
-     * @return Minimum execution time of query.
-     */
-    public long minimumTime();
-
-    /**
-     * Gets maximum execution time of query.
-     *
-     * @return Maximum execution time of query.
-     */
-    public long maximumTime();
-
-    /**
-     * Gets average execution time of query.
-     *
-     * @return Average execution time of query.
-     */
-    public double averageTime();
-
-    /**
-     * Gets total number execution of query.
-     *
-     * @return Number of executions.
-     */
-    public int executions();
-
-    /**
-     * Gets total number of times a query execution failed.
-     *
-     * @return Total number of times a query execution failed.
-     */
-    public int fails();
-}
diff --git a/modules/core/src/main/java/org/apache/ignite/cache/CacheProjection.java b/modules/core/src/main/java/org/apache/ignite/cache/CacheProjection.java
index 2457fcd..c3f141d 100644
--- a/modules/core/src/main/java/org/apache/ignite/cache/CacheProjection.java
+++ b/modules/core/src/main/java/org/apache/ignite/cache/CacheProjection.java
@@ -18,11 +18,11 @@
 package org.apache.ignite.cache;
 
 import org.apache.ignite.*;
-import org.apache.ignite.cache.query.*;
 import org.apache.ignite.cache.store.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.internal.*;
 import org.apache.ignite.internal.processors.cache.*;
+import org.apache.ignite.internal.processors.cache.query.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.transactions.*;
 import org.jetbrains.annotations.*;
@@ -98,7 +98,7 @@ import java.util.concurrent.*;
  *  operations within a transaction (see {@link IgniteTx} for more information).
  * </li>
  * <li>
  *  {@link #queries()} method to get an instance of {@link org.apache.ignite.cache.query.CacheQueries} service for working
  *  with distributed cache queries.
  * </li>
  * <li>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/aa0ee770/modules/core/src/main/java/org/apache/ignite/cache/query/CacheContinuousQuery.java
----------------------------------------------------------------------
@@ -98,7 +98,7 @@ import java.util.concurrent.*;
  * </li>
  * <li>
- *  {@link #queries()} method to get an instance of {@link org.apache.ignite.cache.query.CacheQueries} service for working
+ *  {@link #queries()} method to get an instance of {@link org.apache.ignite.internal.processors.cache.query.CacheQueries} service for working
  *  with distributed cache queries.
  * </li>